@@ -9,7 +9,7 @@ RegisteredOption = namedtuple(
     "RegisteredOption", 
     "key defval doc validator"
 )
-age_interval = [-5, 0]
+age_down_to = 40
 age_max = 99
 comp_neg_temp_out = 'TEM'
 comp_neg_emi = 'EMI'
@@ -35,10 +35,10 @@ pop_start = 'Initial Population'
 
 
 
-def is_int(x):
+def is_int(x, opname):
     if not isinstance(x, int):
-        msg1 = "age.max must be an int, not of {}."
-        raise TypeError(msg1.format(type(x)))
+        type_x = type(x)
+        raise TypeError(f"{opname} must be an int, not of {type_x}.")
     return None
 
 def is_str(x, opname, can_be_None = True):
@@ -147,6 +147,8 @@ def is_method(x):
 
     return None
 
+is_int_age_max = lambda x: is_int(x, 'age.max')
+is_int_age_down_to = lambda x: is_int(x, 'age.down_to')
 is_str_comp_neg_temp_out = lambda x: is_str(x, 'comp_neg.temp_out')
 is_str_comp_neg_emi = lambda x: is_str(x, 'comp_neg.emi')
 is_str_comp_neg_npr_out = lambda x: is_str(x, 'comp_neg.npr_out')
@@ -170,7 +172,7 @@ is_list_containing_comp_end = lambda x: is_list_containing(x, 'comp.end')
 
 _global_config = {
     'age': {
-        'interval': age_interval,
+        'down_to': age_down_to,
         'max': age_max
     },
     'comp': {
@@ -203,14 +205,17 @@ _global_config = {
     }
 }
 _registered_options = {
-    'age.interval': RegisteredOption(
-        key = 'age.interval',
-        defval = age_interval,
+    'age.down_to': RegisteredOption(
+        key = 'age.down_to',
+        defval = age_down_to,
         doc =\
-            "\n (list of int)\n " +\
-            "A closed interval of ages to consider when applying " +\
-            "correction to a population table.",
-        validator = is_list_int_ordered
+            "\n (int)\n    " +\
+            "A bottom level of the neighbouring ages for the " +\
+            "problematic age. Counter-adjustments are applied " +\
+            "from the maximum neighbouring age and " +\
+            "all the way down to the maximum of -1 and " +\
+            "age of modification - age.down_to.",
+        validator = is_int_age_down_to
     ),
     'age.max': RegisteredOption(
         key = 'age.max',
@@ -221,7 +226,7 @@ _registered_options = {
             'this option is classified as the "plus category." ' +\
             'That is, if `age.max` == 99 (default), then any age ' +\
             'greater than or equal to 100 is classified as `100+`.', 
-        validator = is_int
+        validator = is_int_age_max
     ),
     'comp.end': RegisteredOption(
         key = 'comp.end',
