@@ -1165,6 +1165,7 @@ def calculate_ages_to_modify_and_counter(
 
     Examples
     --------
+    >>> # age.down_to == 40
     >>> # age.max == 99
     >>> age1 = Age(97)
     >>> age2 = Age('100+') # maximum age
@@ -1206,13 +1207,14 @@ def calculate_ages_to_modify_and_counter(
     True
     '''
 
+    age_down_to = get_option('age.down_to')
     age_is_max = problematic_age.is_max()
     to_modify_age_str = str(problematic_age.get_showing_age())
     to_modify_age_int = int(to_modify_age_str) - 1
     if comp_in_comp_end:
         to_modify_age_int += 1
     to_counter_age_max = to_modify_age_int - 1
-    to_counter_age_min = max(to_modify_age_int - 40, -1)
+    to_counter_age_min = max(to_modify_age_int - age_down_to, -1)
     to_modify_age_int_lst = None
     result = {}
     if age_is_max and not comp_in_comp_end:
@@ -1349,8 +1351,12 @@ def calculate_modifiable_in_comp(
                     modifiable_val_in_comp_1
                 modifiable_0 = min(leftover, modifiable_val_in_comp_0)
         else:
-            modifiable_0 = abs_modifiable_val_in_pop_end // 2
-            modifiable_1 = abs_modifiable_val_in_pop_end - modifiable_0
+            modifiable_0 =\
+                modifiable_val_in_comp_0 +\
+                (abs_modifiable_val_in_pop_end // 2)
+            modifiable_1 =\
+                modifiable_val_in_comp_1 +\
+                abs_modifiable_val_in_pop_end - modifiable_0
         modifiable = [modifiable_0, modifiable_1]
     else:
         raise NotImplementedError
